@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2024 Free Software Foundation, Inc.
+// Copyright (C) 2004-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -31,12 +31,12 @@ void test06(void)
   // seekg
   {
     wistringstream iss(num1);
-    wistream::pos_type pos1 = iss.tellg();
+    iss.tellg();
     int asNum = 0;
     iss >> asNum;
     VERIFY( iss.eof() );
     VERIFY( !iss.fail() );
-    iss.seekg(pos1);
+    iss.seekg(0, ios_base::beg);
     VERIFY( !iss.fail() );
   }
 }
